function [I,k]=integ_classique(type,a,b,e,f)
% INTEG_CLASSIQUE   Approximation d'intgrale - mthodes classiques
%   [I,K] = INTEG_CLASSIQUE(TYPE,A,B,E,F)  renvoie l'approximation de
%   l'intgrale de F sur l'intervalle [A,B], avec la mthode de TYPE donn.
%   La prcision E est  prcise.  noter : plus de prcision implique
%   plus de calculs. On peut estimer le nombre de calcul par K, nombre de
%   points qui doivent tre connus pour calculer avec E demand.
%
%   [I,K] = INTEG_CLASSIQUE('rectangle',A,B,E,F) : mthode des rectangles.
%   [I,K] = INTEG_CLASSIQUE('trapeze',A,B,E,F) : mthode des trapzes.
%   [I,K] = INTEG_CLASSIQUE('simpson',A,B,E,F) : mthode de Simpson.
%
%   Example:
%   [I,k] = integ_classique('rectangle',0,0.5,0.00001,'sin(x)')
%
%   See also INTEG_GAUSSIENNE

%   Copyright 2006 Laurent Couvidou

% Points pour la recherche du maximum
x = a:(b-a)/1000000:b;
y = eval(f);

switch(type)

    case('rectangle')
        
        % Recherche du maximum
        M = max(abs(derivee_approx(x,y,1)));
        % Pas thorique correspondant
        hmax = 2*e/(M*(b-a));
        % Nombre d'intervalles
        n = floor((b-a)/hmax);
        % Pas rel
        h = (b-a)/n;
        % Nombre de points
        k = n;
        % Calcul de l'intgrale approche
        x = a:h:b-h; % Les xi
        I = h*sum(eval(f));

    case('milieu')
        
        % Recherche du maximum
        M = max(abs(derivee_approx(x,y,2)));
        % Pas thorique correspondant
        hmax = sqrt(24*e/(M*(b-a)));
        % Nombre d'intervalles
        n = floor((b-a)/hmax);
        % Pas rel
        h = (b-a)/n;
        % Nombre de points
        k = n;
        % Calcul de l'intgrale approche
        x = a+h/2:h:b-h/2; % Les milieux (xi + h/2)
        I = h*sum(eval(f));

    case('trapeze')

        % Recherche du maximum
        M = max(abs(derivee_approx(x,y,2)));
        % Pas thorique correspondant
        hmax = sqrt(12*e/(M*(b-a)));
        % Nombre d'intervalles
        n = floor((b-a)/hmax);
        % Pas rel
        h = (b-a)/n;
        % Nombre de points
        k = n+1;
        % Calcul de l'intgrale approche
        x = a; fa = eval(f); % f(A)
        x = b; fb = eval(f); % f(B)
        x = a+h:h:b-h; % Les xi
        I = h*(fa+fb)/2+h*sum(eval(f));
    
    case('simpson')

        % Recherche du maximum
        M = max(abs(derivee_approx(x,y,4)));
        % Pas thorique correspondant
        hmax = (2880*e/(M*(b-a)))^(1/4);
        % Nombre d'intervalles
        n = floor((b-a)/hmax);
        % Pas rel
        h = (b-a)/n;
        % Nombre de points
        k = 2*n+1;
        % Calcul de l'intgrale approche
        x = a; fa = eval(f); % f(A)
        x = b; fb = eval(f); % f(B)
        x = a+h:h:b-h; % Les xi
        somme_xi = sum(eval(f)); % Leur somme
        x = a+h/2:h:b-h/2; % Les milieus
        somme_milieux = sum(eval(f)); % Leur somme
        I = h*(fa+fb+2*somme_xi+4*somme_milieux)/6;
    
    otherwise
        error(['Mthode ',type,' inconnue'])

end

end