function P=polys_ortho(type, n_max)
%POLY_ORTHO Suite des polygones orthogonaux pour les mthodes gaussiennes 
%   %fonction de calcul des n_max premiers polynomes orthogonaux de Legendre et Tchebychev
% Cette fonction renvoie L et T, deux tableaux contenant les termes dfinis
% par rcurence et pL et pT deux matrices contenant les polynomes (en ligne)
% et les coefficients (en colonnes)

    % nb: n_max = n+2 ?

    syms x;
    
    % Calcul des polynomes othogonaux en symbolique
    switch(type)
        case {0,'leg','legendre'}
            L(1) = 1*x/x;
            L(2) = x; 
            for n = 1:n_max-2
                L(n+2) = expand(x*(2*n+1)*L(n+1)/(n+1)-n*L(n)/(n+1));
            end
            Psym = L;
    
        case {1,'tche','tchebychev'}
            T(1) = 1*x/x;
            T(2) = x; 
            for n = 1:n_max-2
                T(n+2) = expand(2*x*T(n+1)-T(n));
            end
            Psym = T;
    end
    
    % Conversion en polynomes Matlab
    P = zeros(n_max,n_max);
    for i=1:n_max
        P(i,n_max-i+1:n_max) = sym2poly(Psym(i));
    end
    
end